{
  pkgs,
  inputs,
  ...
}: {
  imports = [
    ../../modules/home
  ];

  kanshi.enable = true;
  kanshi.laptop = true;

  waybar.enable = true;
  waybar.squeekboard = true;
  waybar.mpd = true;
  waybar.battery = true;
  waybar.backlight = true;

  # Home Manager needs a bit of information about you and the paths it should
  # manage.
  home.username = "max";
  home.homeDirectory = "/home/max";

  # This value determines the Home Manager release that your configuration is
  # compatible with. This helps avoid breakage when a new Home Manager release
  # introduces backwards incompatible changes.
  #
  # You should not change this value, even if you update Home Manager. If you do
  # want to update the value, then make sure to first check the Home Manager
  # release notes.
  home.stateVersion = "23.11"; # Please read the comment before changing.

  # The home.packages option allows you to install Nix packages into your
  # environment.
  home.packages = with pkgs; [
    unzip
    nextcloud-client
    firefox
    thunderbird
    xournalpp
    prismlauncher
    steam
    blender
    betaflight-configurator
    loudgain
    youtube-dl
    dconf
    distrobox
    libqalculate
    sops
    pwvucontrol
    qpwgraph
    discord
    libreoffice-fresh
    mate.caja
    libsForQt5.okular
    mpv
    gimp
    freecad
    flatpak
    wine
    unstable.gyroflow
    prusa-slicer
  ];

  home.sessionVariables = {
    EDITOR = "${pkgs.neovim}/bin/nvim";
  };

  xdg.enable = true;

  services.nextcloud-client.enable = true;

  services.udiskie = {
    enable = true;
    automount = true;
    notify = true;
  };

  # Let Home Manager install and manage itself.
  programs.home-manager.enable = true;

  programs.direnv = {
    enable = true;
    enableBashIntegration = true;
    enableZshIntegration = true;
  };
}
